@@ -16,7 +16,10 @@ email                : fh@ez.no
  ***************************************************************************/
 
 #include "debug.h"
+#include "collectiondb.h"
 #include "engineobserver.h"
+#include "metabundle.h"
+#include "podcastbundle.h"
 #include <qptrlist.h>
 
 
@@ -75,18 +78,26 @@ void EngineSubject::newMetaDataNotify( const MetaBundle &bundle, bool trackChang
 
     QPtrListIterator<EngineObserver> it( Observers );
     EngineObserver *observer;
+
+    PodcastEpisodeBundle peb;
+    MetaBundle b( bundle );
+    if( CollectionDB::instance()->getPodcastEpisodeBundle( bundle.url(), &peb ) )
+    {
+        b.setPodcastBundle( peb );
+    }
+
     while( ( observer = it.current() ) != 0 )
     {
         ++it;
-        observer->engineNewMetaData( bundle, trackChanged );
+        observer->engineNewMetaData( b, trackChanged );
     }
 }
 
 
-void EngineSubject::trackEnded( int finalPosition, int trackLength )
+void EngineSubject::trackEnded( int finalPosition, int trackLength, const QString &reason )
 {
     for( QPtrListIterator<EngineObserver> it( Observers ); *it; ++it )
-        (*it)->engineTrackEnded( finalPosition, trackLength );
+        (*it)->engineTrackEnded( finalPosition, trackLength, reason );
 }
 
 
@@ -114,6 +125,18 @@ void EngineSubject::trackPositionChangedNotify( long position, bool userSeek )
 }
 
 
+void EngineSubject::trackLengthChangedNotify( long length )
+{
+    QPtrListIterator<EngineObserver> it( Observers );
+    EngineObserver *observer;
+    while( ( observer = it.current() ) != 0 )
+    {
+        ++it;
+        observer->engineTrackLengthChanged( length );
+    }
+}
+
+
 void EngineSubject::attach( EngineObserver *observer )
 {
     if( !observer || Observers.find( observer ) != -1 )
